Stone's Statistics
=
Why is the name "stone's statistics"?
-
#### !WARNING! The content is worthless to read!
Many people think "why is the name 'stone'?" because stone isn't living. But the owner's last name is 'STONE'!

PURPOSE
=
Nothing. just  **JOY**!